==> N3-components-1.0.6.tgz: package/README.md <==
N3-components - Powerful Vue Library.
=========================

[![Shippable branch](https://img.shields.io/shippable/5444c5ecb904a4b21567b0ff/master.svg?maxAge=2592000)]()
[![Test Coverage](https://codeclimate.com/github/N3-components/N3-components/badges/coverage.svg)](https://codeclimate.com/github/N3-components/N3-components/coverage)
[![Gitter](https://img.shields.io/gitter/room/nwjs/nw.js.svg?maxAge=2592000)](https://gitter.im/N3-components/english?utm_source=share-link&utm_medium=link&utm_campaign=share-link)
[![Code Climate](https://codeclimate.com/github/N3-components/N3-components/badges/gpa.svg)](https://codeclimate.com/github/N3-components/N3-components)
[![npm](https://img.shields.io/npm/l/express.svg?maxAge=2592000)]()

N3 components library is built with Vue.js, is a powerful library for frontend or full-stack engineers to build web pages quickly.

[Home Page](https://n3-components.github.io/N3-components/) | [中文说明](./README-zh.md) | [Documents](https://n3-components.github.io/N3-components/component.html)

Introduction
------------

![logo](https://n3-components.github.io/N3-components/static/img/logo.png)

N3 components applys oneself to structure a great ecological circle of developers using Vue.js. Supporting as follows:

* More than 60 components. [See Here](./src)

* Personality Of Style.

* UMD.

* Using ES6.

NPM
------------
Link：[https://www.npmjs.com/package/N3-components](https://www.npmjs.com/package/N3-components)

```bash
npm install N3-Components
```

Quick Start
------------

You can install components for your global environment.

```javascript
import Vue from 'vue'
import N3Components from 'N3-Components'
N3Components.install(Vue)
```

You can also import single component when needed.

```javascript
import Vue from 'vue'
import N3Components from 'N3-Components'
import {n3Alert} from N3Components
```

Requirements
------------

* vue
* vue-focus
* velocity-animate

To Do List
----------

- Tree View
- Drawer Menu

Discussing
----------
- [submit issue](https://github.com/N3-components/N3-components/issues/new)
- email: zhangking520@gmail.com
- gitter: [![Gitter](https://img.shields.io/gitter/room/nwjs/nw.js.svg?maxAge=2592000)](https://gitter.im/N3-components/english?utm_source=share-link&utm_medium=link&utm_campaign=share-link)

==> N3-components-1.1.7.tgz: package/README.md <==
N3-components - Powerful Vue Library.
=========================

[![Shippable branch](https://img.shields.io/shippable/5444c5ecb904a4b21567b0ff/master.svg?maxAge=2592000)]()
[![Test Coverage](https://codeclimate.com/github/N3-components/N3-components/badges/coverage.svg)](https://codeclimate.com/github/N3-components/N3-components/coverage)
[![Gitter](https://img.shields.io/gitter/room/nwjs/nw.js.svg?maxAge=2592000)](https://gitter.im/N3-components/english?utm_source=share-link&utm_medium=link&utm_campaign=share-link)
[![Code Climate](https://codeclimate.com/github/N3-components/N3-components/badges/gpa.svg)](https://codeclimate.com/github/N3-components/N3-components)
[![npm](https://img.shields.io/npm/l/express.svg?maxAge=2592000)]()

N3 components library is built with Vue.js, is a powerful library for frontend or full-stack engineers to build web pages quickly.

[Home Page](https://n3-components.github.io/N3-components/) | [中文说明](./README-zh.md) | [Documents](https://n3-components.github.io/N3-components/component.html)

Introduction
------------

![logo](https://n3-components.github.io/N3-components/static/img/logo.png)

N3 components applys oneself to structure a great ecological circle of developers using Vue.js. Supporting as follows:

* More than 60 components. [See Here](./src)

* Personality Of Style.

* UMD.

* Using ES6.

NPM
------------
Link：[https://www.npmjs.com/package/N3-components](https://www.npmjs.com/package/N3-components)

```bash
npm install N3-components
```

Quick Start
------------

You can install components for your global environment.

```javascript
import Vue from 'vue'
import N3Components from 'N3-components'
N3Components.install(Vue)
```

You can also import single component when needed.

```javascript
import Vue from 'vue'
import N3Components from 'N3-components'
import {n3Alert} from N3Components
```

Requirements
------------

* vue
* vue-focus
* velocity-animate

To Do List
----------

- Tree View
- Drawer Menu

Discussing
----------
- [submit issue](https://github.com/N3-components/N3-components/issues/new)
- email: zhangking520@gmail.com
- gitter: [![Gitter](https://img.shields.io/gitter/room/nwjs/nw.js.svg?maxAge=2592000)](https://gitter.im/N3-components/english?utm_source=share-link&utm_medium=link&utm_campaign=share-link)
- QQ Group: 556286036 <a target="_blank" href="http://shang.qq.com/wpa/qunwpa?idkey=ae2b542ef32e8595664c746572d9a48187167e269ef5b6c80d8ed326fce5efdd"><img border="0" src="http://pub.idqqimg.com/wpa/images/group.png" alt="N3-components交流群" title="N3-components交流群"></a>
- QQ Group Qrcode:
![qrcode](https://n3-components.github.io/N3-components/static/img/N3-QQ.png)
